@@ -1,10 +1,13 @@
+import abc
 from typing import Any, Callable, Optional as O
 from pydantic import BaseModel, validator
 from graia.application.message.chain import MessageChain
 import regex
 
-class NormalMatch(BaseModel):
-    pass
+class NormalMatch(BaseModel, abc.ABC):
+    @abc.abstractmethod
+    def operator(self) -> str:
+        pass
 
 class PatternReceiver(BaseModel):
     name: str
@@ -28,6 +31,15 @@ class FullMatch(NormalMatch):
     def operator(self):
         return regex.escape(self.pattern)
 
+class RegexMatch(NormalMatch):
+    pattern: str
+
+    def __init__(self, pattern) -> None:
+        super().__init__(pattern=pattern)
+    
+    def operator(self):
+        return self.pattern
+
 class RequireParam(PatternReceiver):
     checker: O[Callable[[MessageChain], bool]] = None
     translator: O[Callable[[MessageChain], Any]] = None
